@@ -1,23 +1,23 @@
 import logging
 import os
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any, List
 
+from multiversx_sdk_core import Address, Transaction
 from multiversx_sdk_network_providers.proxy_network_provider import \
     ProxyNetworkProvider
 
 from multiversx_sdk_cli import cli_shared, errors, projects, utils
-from multiversx_sdk_cli.accounts import Account, Address, LedgerAccount
+from multiversx_sdk_cli.accounts import Account, LedgerAccount
 from multiversx_sdk_cli.cli_output import CLIOutputBuilder
 from multiversx_sdk_cli.cli_password import load_password
 from multiversx_sdk_cli.contract_verification import \
     trigger_contract_verification
 from multiversx_sdk_cli.contracts import CodeMetadata, SmartContract
+from multiversx_sdk_cli.cosign_transaction import cosign_transaction
 from multiversx_sdk_cli.docker import is_docker_installed, run_docker
-from multiversx_sdk_cli.errors import DockerMissingError
-from multiversx_sdk_cli.projects import load_project
+from multiversx_sdk_cli.errors import DockerMissingError, NoWalletProvided
 from multiversx_sdk_cli.projects.core import get_project_paths_recursively
-from multiversx_sdk_cli.transactions import Transaction
 
 logger = logging.getLogger("cli.contracts")
 
@@ -40,14 +40,11 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
 
     sub = cli_shared.add_command_subparser(subparsers, "contract", "build",
                                            "Build a Smart Contract project using the appropriate buildchain.")
-    _add_project_arg(sub)
-    _add_recursive_arg(sub)
-    _add_build_options_args(sub)
+    _add_build_options_sc_meta(sub)
     sub.set_defaults(func=build)
 
     sub = cli_shared.add_command_subparser(subparsers, "contract", "clean", "Clean a Smart Contract project.")
-    _add_project_arg(sub)
-    _add_recursive_arg(sub)
+    sub.add_argument("--path", default=os.getcwd(), help="the project directory (default: current directory)")
     sub.set_defaults(func=clean)
 
     sub = cli_shared.add_command_subparser(subparsers, "contract", "test", "Run scenarios (tests).")
@@ -59,29 +56,29 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
     sub.set_defaults(func=run_tests)
 
     sub = cli_shared.add_command_subparser(subparsers, "contract", "report", "Print a detailed report of the smart contracts.")
-    _add_project_arg(sub)
     sub.add_argument("--skip-build", action="store_true", default=False, help="skips the step of building of the wasm contracts")
     sub.add_argument("--skip-twiggy", action="store_true", default=False, help="skips the steps of building the debug wasm files and running twiggy")
     sub.add_argument("--output-format", type=str, default="text-markdown", choices=["github-markdown", "text-markdown", "json"], help="report output format (default: %(default)s)")
     sub.add_argument("--output-file", type=Path, help="if specified, the output is written to a file, otherwise it's written to the standard output")
     sub.add_argument("--compare", type=Path, nargs='+', metavar=("report-1.json", "report-2.json"), help="create a comparison from two or more reports")
-    _add_build_options_args(sub)
+    _add_build_options_sc_meta(sub)
     sub.set_defaults(func=do_report)
 
     output_description = CLIOutputBuilder.describe(with_contract=True, with_transaction_on_network=True, with_simulation=True)
     sub = cli_shared.add_command_subparser(subparsers, "contract", "deploy", f"Deploy a Smart Contract.{output_description}")
-    _add_project_or_bytecode_arg(sub)
+    _add_bytecode_arg(sub)
     _add_metadata_arg(sub)
     cli_shared.add_outfile_arg(sub)
     cli_shared.add_wallet_args(args, sub)
     cli_shared.add_proxy_arg(sub)
-    cli_shared.add_tx_args(args, sub, with_receiver=False, with_data=False)
+    cli_shared.add_tx_args(args, sub, with_receiver=False, with_data=False, with_guardian=True)
     _add_arguments_arg(sub)
     sub.add_argument("--wait-result", action="store_true", default=False,
                      help="signal to wait for the transaction result - only valid if --send is set")
     sub.add_argument("--timeout", default=100, help="max num of seconds to wait for result"
                                                     " - only valid if --wait-result is set")
     cli_shared.add_broadcast_args(sub)
+    cli_shared.add_guardian_wallet_args(args, sub)
 
     sub.set_defaults(func=deploy)
 
@@ -91,7 +88,7 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
     cli_shared.add_outfile_arg(sub)
     cli_shared.add_wallet_args(args, sub)
     cli_shared.add_proxy_arg(sub)
-    cli_shared.add_tx_args(args, sub, with_receiver=False, with_data=False)
+    cli_shared.add_tx_args(args, sub, with_receiver=False, with_data=False, with_guardian=True)
     _add_function_arg(sub)
     _add_arguments_arg(sub)
     sub.add_argument("--wait-result", action="store_true", default=False,
@@ -99,6 +96,7 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
     sub.add_argument("--timeout", default=100, help="max num of seconds to wait for result"
                                                     " - only valid if --wait-result is set")
     cli_shared.add_broadcast_args(sub, relay=True)
+    cli_shared.add_guardian_wallet_args(args, sub)
 
     sub.set_defaults(func=call)
 
@@ -106,17 +104,18 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
                                            f"Upgrade a previously-deployed Smart Contract.{output_description}")
     _add_contract_arg(sub)
     cli_shared.add_outfile_arg(sub)
-    _add_project_or_bytecode_arg(sub)
+    _add_bytecode_arg(sub)
     _add_metadata_arg(sub)
     cli_shared.add_wallet_args(args, sub)
     cli_shared.add_proxy_arg(sub)
-    cli_shared.add_tx_args(args, sub, with_receiver=False, with_data=False)
+    cli_shared.add_tx_args(args, sub, with_receiver=False, with_data=False, with_guardian=True)
     _add_arguments_arg(sub)
     sub.add_argument("--wait-result", action="store_true", default=False,
                      help="signal to wait for the transaction result - only valid if --send is set")
     sub.add_argument("--timeout", default=100, help="max num of seconds to wait for result"
                                                     " - only valid if --wait-result is set")
     cli_shared.add_broadcast_args(sub)
+    cli_shared.add_guardian_wallet_args(args, sub)
 
     sub.set_defaults(func=upgrade)
 
@@ -128,12 +127,9 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
     _add_arguments_arg(sub)
     sub.set_defaults(func=query)
 
-    sub = cli_shared.add_command_subparser(
-        subparsers,
-        "contract",
-        "verify",
-        "Verify the authenticity of the code of a deployed Smart Contract",
-    )
+    sub = cli_shared.add_command_subparser(subparsers, "contract", "verify",
+                                           "Verify the authenticity of the code of a deployed Smart Contract",
+                                           )
 
     sub.add_argument(
         "--packaged-src", required=True, help="JSON file containing the source code of the contract"
@@ -146,6 +142,7 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
         help="the url of the service that validates the contract",
     )
     sub.add_argument("--docker-image", required=True, help="the docker image used for the build")
+    sub.add_argument("--contract-variant", required=False, default=None, help="in case of a multicontract, specify the contract variant you want to verify")
     cli_shared.add_wallet_args(args, sub)
     sub.set_defaults(func=verify)
 
@@ -171,6 +168,29 @@ def _add_project_arg(sub: Any):
                      help="🗀 the project directory (default: current directory)")
 
 
+def _add_build_options_sc_meta(sub: Any):
+    sub.add_argument("--path", default=os.getcwd(), help="the project directory (default: current directory)")
+    sub.add_argument("--no-wasm-opt", action="store_true", default=False,
+                     help="do not optimize wasm files after the build (default: %(default)s)")
+    sub.add_argument("--wasm-symbols", action="store_true", default=False,
+                     help="for rust projects, does not strip the symbols from the wasm output. Useful for analysing the bytecode. Creates larger wasm files. Avoid in production (default: %(default)s)")
+    sub.add_argument("--wasm-name", type=str,
+                     help="for rust projects, optionally specify the name of the wasm bytecode output file")
+    sub.add_argument("--wasm-suffix", type=str,
+                     help="for rust projects, optionally specify the suffix of the wasm bytecode output file")
+    sub.add_argument("--target-dir", type=str, help="for rust projects, forward the parameter to Cargo")
+    sub.add_argument("--wat", action="store_true", help="also generate a WAT file when building", default=False)
+    sub.add_argument("--mir", action="store_true", help="also emit MIR files when building", default=False)
+    sub.add_argument("--llvm-ir", action="store_true", help="also emit LL (LLVM) files when building", default=False)
+    sub.add_argument("--ignore", help="ignore all directories with these names. [default: target]")
+    sub.add_argument("--no-imports", action="store_true", default=False, help="skips extracting the EI imports after building the contracts")
+    sub.add_argument("--no-abi-git-version", action="store_true", default=False, help="skips loading the Git version into the ABI")
+    sub.add_argument("--twiggy-top", action="store_true", default=False, help="generate a twiggy top report after building")
+    sub.add_argument("--twiggy-paths", action="store_true", default=False, help="generate a twiggy paths report after building")
+    sub.add_argument("--twiggy-monos", action="store_true", default=False, help="generate a twiggy monos report after building")
+    sub.add_argument("--twiggy-dominators", action="store_true", default=False, help="generate a twiggy dominators report after building")
+
+
 def _add_build_options_args(sub: Any):
     sub.add_argument("--debug", action="store_true", default=False, help="set debug flag (default: %(default)s)")
     sub.add_argument("--no-optimization", action="store_true", default=False,
@@ -185,22 +205,14 @@ def _add_build_options_args(sub: Any):
     sub.add_argument("--wasm-suffix", type=str,
                      help="for rust projects, optionally specify the suffix of the wasm bytecode output file")
 
-    sub.add_argument("--eei-checks", action="store_true", default=False, help="run EEI compatibility checks (default: %(default)s)")
-    # Flags are kept in order to avoid breaking changes, for the moment - we might completely remove them in the future.
-    sub.add_argument("--skip-eei-checks", action="store_true", default=True, help="deprecated flag")
-    sub.add_argument("--ignore-eei-checks", action="store_true", default=True, help="deprecated flag")
-
 
 def _add_recursive_arg(sub: Any):
     sub.add_argument("-r", "--recursive", dest="recursive", action="store_true", help="locate projects recursively")
 
 
-def _add_project_or_bytecode_arg(sub: Any):
-    group = sub.add_mutually_exclusive_group(required=True)
-    group.add_argument("--project", default=os.getcwd(),
-                       help="🗀 the project directory (default: current directory)")
-    group.add_argument("--bytecode", type=str,
-                       help="the file containing the WASM bytecode")
+def _add_bytecode_arg(sub: Any):
+    sub.add_argument("--bytecode", type=str, required=True,
+                     help="the file containing the WASM bytecode")
 
 
 def _add_contract_arg(sub: Any):
@@ -250,40 +262,21 @@ def get_project_paths(args: Any) -> List[Path]:
 
 
 def clean(args: Any):
-    project_paths = get_project_paths(args)
-    for project in project_paths:
-        projects.clean_project(project)
+    project_path = args.path
+    projects.clean_project(Path(project_path))
 
 
 def build(args: Any):
-    project_paths = get_project_paths(args)
-    options: Dict[str, Any] = _prepare_build_options(args)
+    project_paths = [Path(args.path)]
+    arg_list = cli_shared.convert_args_object_to_args_list(args)
 
     for project in project_paths:
-        projects.build_project(project, options)
-
-
-def _prepare_build_options(args: Any) -> Dict[str, Any]:
-    return {
-        "debug": args.debug,
-        "optimized": not args.no_optimization,
-        "no-wasm-opt": args.no_wasm_opt,
-        "verbose": args.verbose,
-        "cargo-target-dir": args.cargo_target_dir,
-        "wasm-symbols": args.wasm_symbols,
-        "wasm-name": args.wasm_name,
-        "wasm-suffix": args.wasm_suffix,
-        "eei-checks": args.eei_checks,
-        # TODO: Remove this, in the future
-        "skip-eei-checks": args.skip_eei_checks,
-        # TODO: Remove this, in the future
-        "ignore-eei-checks": args.ignore_eei_checks
-    }
+        projects.build_project(project, arg_list)
 
 
 def do_report(args: Any):
-    build_options: Dict[str, Any] = _prepare_build_options(args)
-    projects.do_report(args, build_options)
+    args_dict = args.__dict__
+    projects.do_report(args, args_dict)
 
 
 def run_tests(args: Any):
@@ -294,32 +287,30 @@ def run_tests(args: Any):
 
 def deploy(args: Any):
     logger.debug("deploy")
+    cli_shared.check_guardian_and_options_args(args)
     cli_shared.check_broadcast_args(args)
 
     arguments = args.arguments
     gas_price = args.gas_price
     gas_limit = args.gas_limit
     value = args.value
-    chain = args.chain
     version = args.version
 
     contract = _prepare_contract(args)
     sender = _prepare_sender(args)
+    cli_shared.prepare_chain_id_in_args(args)
 
-    tx = contract.deploy(sender, arguments, gas_price, gas_limit, value, chain, version)
-    logger.info("Contract address: %s", contract.address)
-    utils.log_explorer_contract_address(chain, contract.address)
+    tx = contract.deploy(sender, arguments, gas_price, gas_limit, value, args.chain, version, args.guardian, args.options)
+    tx = _sign_guarded_tx(args, tx)
+
+    logger.info("Contract address: %s", contract.address.bech32())
+    utils.log_explorer_contract_address(args.chain, contract.address.bech32())
 
     _send_or_simulate(tx, contract, args)
 
 
 def _prepare_contract(args: Any) -> SmartContract:
-    if args.bytecode and len(args.bytecode):
-        bytecode = utils.read_binary_file(Path(args.bytecode)).hex()
-    else:
-        project_path = Path(args.project)
-        project = load_project(project_path)
-        bytecode = project.get_bytecode()
+    bytecode = utils.read_binary_file(Path(args.bytecode)).hex()
 
     metadata = CodeMetadata(upgradeable=args.metadata_upgradeable, readable=args.metadata_readable,
                             payable=args.metadata_payable, payable_by_sc=args.metadata_payable_by_sc)
@@ -364,8 +355,23 @@ def _prepare_signer(args: Any) -> Account:
     return sender
 
 
+def _sign_guarded_tx(args: Any, tx: Transaction) -> Transaction:
+    try:
+        guardian_account = cli_shared.prepare_guardian_account(args)
+    except NoWalletProvided:
+        guardian_account = None
+
+    if guardian_account:
+        tx.guardian_signature = bytes.fromhex(guardian_account.sign_transaction(tx))
+    elif args.guardian:
+        tx = cosign_transaction(tx, args.guardian_service_url, args.guardian_2fa_code)  # type: ignore
+
+    return tx
+
+
 def call(args: Any):
     logger.debug("call")
+    cli_shared.check_guardian_and_options_args(args)
     cli_shared.check_broadcast_args(args)
 
     contract_address = args.contract
@@ -374,13 +380,15 @@ def call(args: Any):
     gas_price = args.gas_price
     gas_limit = args.gas_limit
     value = args.value
-    chain = args.chain
     version = args.version
 
-    contract = SmartContract(contract_address)
+    contract = SmartContract(Address.from_bech32(contract_address))
     sender = _prepare_sender(args)
+    cli_shared.prepare_chain_id_in_args(args)
+
+    tx = contract.execute(sender, function, arguments, gas_price, gas_limit, value, args.chain, version, args.guardian, args.options)
+    tx = _sign_guarded_tx(args, tx)
 
-    tx = contract.execute(sender, function, arguments, gas_price, gas_limit, value, chain, version)
     _send_or_simulate(tx, contract, args)
 
 
@@ -393,14 +401,16 @@ def upgrade(args: Any):
     gas_price = args.gas_price
     gas_limit = args.gas_limit
     value = args.value
-    chain = args.chain
     version = args.version
 
     contract = _prepare_contract(args)
-    contract.address = Address(contract_address)
+    contract.address = Address.from_bech32(contract_address)
     sender = _prepare_sender(args)
+    cli_shared.prepare_chain_id_in_args(args)
+
+    tx = contract.upgrade(sender, arguments, gas_price, gas_limit, value, args.chain, version, args.guardian, args.options)
+    tx = _sign_guarded_tx(args, tx)
 
-    tx = contract.upgrade(sender, arguments, gas_price, gas_limit, value, chain, version)
     _send_or_simulate(tx, contract, args)
 
 
@@ -411,7 +421,7 @@ def query(args: Any):
     function = args.function
     arguments = args.arguments
 
-    contract = SmartContract(contract_address)
+    contract = SmartContract(address=Address.from_bech32(contract_address))
     result = contract.query(ProxyNetworkProvider(args.proxy), function, arguments)
     utils.dump_out_json(result)
 
@@ -423,16 +433,17 @@ def _send_or_simulate(tx: Transaction, contract: SmartContract, args: Any):
 
 
 def verify(args: Any) -> None:
-    contract = Address(args.contract)
+    contract = Address.from_bech32(args.contract)
     verifier_url = args.verifier_url
 
     packaged_src = Path(args.packaged_src).expanduser().resolve()
 
     owner = _prepare_signer(args)
     docker_image = args.docker_image
+    contract_variant = args.contract_variant
 
     trigger_contract_verification(
-        packaged_src, owner, contract, verifier_url, docker_image
+        packaged_src, owner, contract, verifier_url, docker_image, contract_variant
     )
     logger.info("Contract verification request completed!")
 
@@ -451,8 +462,8 @@ def do_reproducible_build(args: Any):
 
     utils.ensure_folder(output_path)
 
-    options = _prepare_build_options(args)
-    no_wasm_opt = options.get("no-wasm-opt", True)
+    options = args.__dict__
+    no_wasm_opt = options.get("no_wasm_opt", False)
 
     if not is_docker_installed():
         raise DockerMissingError()
