@@ -5,12 +5,13 @@ import sys
 from pathlib import Path
 from typing import Any, List, Optional, Tuple
 
+from multiversx_sdk_core import Address
 from multiversx_sdk_wallet import UserSecretKey, UserWallet
 from multiversx_sdk_wallet.mnemonic import Mnemonic
 from multiversx_sdk_wallet.user_pem import UserPEM
 
 from multiversx_sdk_cli import cli_shared
-from multiversx_sdk_cli.accounts import Account, Address
+from multiversx_sdk_cli.constants import DEFAULT_HRP
 from multiversx_sdk_cli.errors import KnownError
 
 logger = logging.getLogger("cli.wallet")
@@ -19,6 +20,9 @@ WALLET_FORMAT_RAW_MNEMONIC = "raw-mnemonic"
 WALLET_FORMAT_KEYSTORE_MNEMONIC = "keystore-mnemonic"
 WALLET_FORMAT_KEYSTORE_SECRET_KEY = "keystore-secret-key"
 WALLET_FORMAT_PEM = "pem"
+WALLET_FORMAT_ADDRESS_BECH32 = "address-bech32"
+WALLET_FORMAT_ADDRESS_HEX = "address-hex"
+
 WALLET_FORMATS = [
     WALLET_FORMAT_RAW_MNEMONIC,
     WALLET_FORMAT_KEYSTORE_MNEMONIC,
@@ -26,6 +30,8 @@ WALLET_FORMATS = [
     WALLET_FORMAT_PEM,
 ]
 
+WALLET_FORMATS_AND_ADDRESSES = [*WALLET_FORMATS, WALLET_FORMAT_ADDRESS_BECH32, WALLET_FORMAT_ADDRESS_HEX]
+
 
 def setup_parser(args: List[str], subparsers: Any) -> Any:
     parser = cli_shared.add_group_subparser(
@@ -41,38 +47,23 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
         "new",
         "Create a new wallet and print its mnemonic; optionally save as password-protected JSON (recommended) or PEM (not recommended)"
     )
-    sub.add_argument("--json", help="DEPRECATED, replaced by --format=keystore-mnemonic", action="store_true", default=False)
-    sub.add_argument("--pem", help="DEPRECATED, replaced by --format=pem", action="store_true", default=False)
-    sub.add_argument("--output-path", help="DEPRECATED, replaced by --outfile", type=str)
     sub.add_argument("--format", choices=WALLET_FORMATS, help="the format of the generated wallet file (default: %(default)s)", default=None)
     sub.add_argument("--outfile", help="the output path and base file name for the generated wallet files (default: %(default)s)", type=str)
-    sub.add_argument("--address-hrp", help=f"the human-readable part of the address, when format is {WALLET_FORMAT_KEYSTORE_SECRET_KEY} or {WALLET_FORMAT_PEM} (default: %(default)s)", type=str, default="erd")
+    sub.add_argument("--address-hrp", help=f"the human-readable part of the address, when format is {WALLET_FORMAT_KEYSTORE_SECRET_KEY} or {WALLET_FORMAT_PEM} (default: %(default)s)", type=str, default=DEFAULT_HRP)
     sub.set_defaults(func=wallet_new)
 
-    sub = cli_shared.add_command_subparser(
-        subparsers,
-        "wallet",
-        "derive",
-        "DEPRECATED COMMAND, replaced by 'wallet convert'"
-    )
-    sub.add_argument("pem", help="path of the output PEM file")
-    sub.add_argument("--mnemonic", action="store_true", help="whether to derive from an existing mnemonic")
-    sub.add_argument("--index", help="the address index", type=int, default=0)
-    sub.set_defaults(func=wallet_derive_deprecated)
-
     sub = cli_shared.add_command_subparser(
         subparsers,
         "wallet",
         "convert",
         "Convert a wallet from one format to another"
     )
-
     sub.add_argument("--infile", help="path to the input file")
     sub.add_argument("--outfile", help="path to the output file")
     sub.add_argument("--in-format", required=True, choices=WALLET_FORMATS, help="the format of the input file")
-    sub.add_argument("--out-format", required=True, choices=WALLET_FORMATS, help="the format of the output file")
+    sub.add_argument("--out-format", required=True, choices=WALLET_FORMATS_AND_ADDRESSES, help="the format of the output file")
     sub.add_argument("--address-index", help=f"the address index, if input format is {WALLET_FORMAT_RAW_MNEMONIC}, {WALLET_FORMAT_KEYSTORE_MNEMONIC} or {WALLET_FORMAT_PEM} (with multiple entries) and the output format is {WALLET_FORMAT_KEYSTORE_SECRET_KEY} or {WALLET_FORMAT_PEM}", type=int, default=0)
-    sub.add_argument("--address-hrp", help=f"the human-readable part of the address, when the output format is {WALLET_FORMAT_KEYSTORE_SECRET_KEY} or {WALLET_FORMAT_PEM} (default: %(default)s)", type=str, default="erd")
+    sub.add_argument("--address-hrp", help=f"the human-readable part of the address, when the output format is {WALLET_FORMAT_KEYSTORE_SECRET_KEY} or {WALLET_FORMAT_PEM} (default: %(default)s)", type=str, default=DEFAULT_HRP)
     sub.set_defaults(func=convert_wallet)
 
     sub = cli_shared.add_command_subparser(
@@ -87,26 +78,6 @@ def setup_parser(args: List[str], subparsers: Any) -> Any:
     group.add_argument("--decode", action="store_true", help="whether to decode")
     sub.set_defaults(func=do_bech32)
 
-    sub = cli_shared.add_command_subparser(
-        subparsers,
-        "wallet",
-        "pem-address",
-        "Get the public address out of a PEM file as bech32"
-    )
-    sub.add_argument("pem", help="path to the PEM file")
-    sub.add_argument("--pem-index", default=0, help="🔑 the index in the PEM file (default: %(default)s)")
-    sub.set_defaults(func=pem_address)
-
-    sub = cli_shared.add_command_subparser(
-        subparsers,
-        "wallet",
-        "pem-address-hex",
-        "Get the public address out of a PEM file as hex"
-    )
-    sub.add_argument("pem", help="path to the PEM file")
-    sub.add_argument("--pem-index", default=0, help="🔑 the index in the PEM file (default: %(default)s)")
-    sub.set_defaults(func=pem_address_hex)
-
     parser.epilog = cli_shared.build_group_epilog(subparsers)
     return subparsers
 
@@ -116,17 +87,6 @@ def wallet_new(args: Any):
     outfile = args.outfile
     address_hrp = args.address_hrp
 
-    # Handle deprecated options
-    if args.json:
-        logger.warning("The --json option is deprecated, use --format=keystore-mnemonic instead.")
-        format = "keystore-mnemonic"
-    if args.pem:
-        logger.warning("The --pem option is deprecated, use --format=pem instead.")
-        format = "pem"
-    if args.output_path:
-        logger.warning("The --output-path option is deprecated, use --outfile instead.")
-        outfile = args.output_path
-
     mnemonic = Mnemonic.generate()
     print(f"Mnemonic: {mnemonic.get_text()}")
 
@@ -254,49 +214,36 @@ def _create_wallet_content(
         pem = UserPEM(address.bech32(), secret_key)
         return pem.to_text()
 
-    raise KnownError(f"Cannot create wallet, unknown output format: <{out_format}>. Make sure to use one of following: {WALLET_FORMATS}.")
+    if out_format == WALLET_FORMAT_ADDRESS_BECH32:
+        if mnemonic:
+            secret_key = mnemonic.derive_key(address_index)
+        assert secret_key is not None
 
-
-def wallet_derive_deprecated(args: Any):
-    logger.warning("This command is deprecated. Use 'wallet convert' instead.")
-
-    pem_file_path = Path(args.pem)
-    ask_mnemonic = args.mnemonic
-    index = args.index
-
-    if ask_mnemonic:
-        mnemonic_str = input("Enter mnemonic:\n").rstrip().replace("\n", "")
-        mnemonic = Mnemonic(mnemonic_str)
-        secret_key = mnemonic.derive_key(index)
         pubkey = secret_key.generate_public_key()
-    else:
-        mnemonic = Mnemonic.generate()
+        address = pubkey.to_address(address_hrp)
+        return address.bech32()
 
-    secret_key = mnemonic.derive_key(index)
-    pubkey = secret_key.generate_public_key()
-    address = Address(pubkey.hex())
+    if out_format == WALLET_FORMAT_ADDRESS_HEX:
+        if mnemonic:
+            secret_key = mnemonic.derive_key(address_index)
+        assert secret_key is not None
 
-    pem_file = UserPEM(address.bech32(), secret_key)
-    pem_file.save(pem_file_path)
+        pubkey = secret_key.generate_public_key()
+        return pubkey.hex()
 
-    logger.info(f"Created PEM file [{pem_file_path}] for [{address.bech32()}]")
+    raise KnownError(f"Cannot create wallet, unknown output format: <{out_format}>. Make sure to use one of following: {WALLET_FORMATS}.")
 
 
 def do_bech32(args: Any):
     encode = args.encode
     value = args.value
-    address = Address(value)
 
-    result = address.bech32() if encode else address.hex()
+    if encode:
+        address = Address.from_hex(value, DEFAULT_HRP)
+        result = address.bech32()
+    else:
+        address = Address.from_bech32(value)
+        result = address.hex()
+
     print(result)
     return result
-
-
-def pem_address(args: Any):
-    account = Account(pem_file=args.pem, pem_index=args.pem_index)
-    print(account.address)
-
-
-def pem_address_hex(args: Any):
-    account = Account(pem_file=args.pem, pem_index=args.pem_index)
-    print(account.address.hex())
