@@ -107,11 +107,11 @@ def write_file(file_path: Path, text: str):
         return file.write(text)
 
 
-def read_toml_file(filename):
+def read_toml_file(filename: Union[str, Path]):
     return toml.load(str(filename))
 
 
-def write_toml_file(filename, data):
+def write_toml_file(filename: Union[str, Path], data: Any):
     with open(str(filename), "w") as f:
         toml.dump(data, f)
 
@@ -121,8 +121,8 @@ def read_json_file(filename: Union[str, Path]) -> Any:
         return json.load(f)
 
 
-def write_json_file(filename: str, data: Any):
-    with open(filename, "w") as f:
+def write_json_file(filename: Union[str, Path], data: Any):
+    with open(str(filename), "w") as f:
         json.dump(data, f, indent=4)
 
 
@@ -239,16 +239,7 @@ def query_latest_release_tag(repo: str) -> str:
     return latest_release_tag
 
 
-# https://code.visualstudio.com/docs/python/debugging
-def breakpoint():
-    import debugpy
-    debugpy.listen(5678)
-    print("Waiting for debugger attach")
-    debugpy.wait_for_client()
-    debugpy.breakpoint()
-
-
-def log_explorer(chain, name, path, details):
+def log_explorer(chain: str, name: str, path: str, details: str):
     networks = {
         "1": ("MultiversX Mainnet Explorer", "https://explorer.multiversx.com"),
         "T": ("MultiversX Testnet Explorer", "https://testnet-explorer.multiversx.com"),
@@ -261,9 +252,9 @@ def log_explorer(chain, name, path, details):
         return
 
 
-def log_explorer_contract_address(chain, address):
+def log_explorer_contract_address(chain: str, address: str):
     log_explorer(chain, "contract address", "accounts", address)
 
 
-def log_explorer_transaction(chain, transaction_hash):
+def log_explorer_transaction(chain: str, transaction_hash: str):
     log_explorer(chain, "transaction", "transactions", transaction_hash)
